@@ -1,8 +1,6 @@
-import requests
 import logging
 import pandas as pd
 
-
 class Symbols(object):
     def __init__(self):
         """
@@ -12,6 +10,12 @@ class Symbols(object):
         self.logger = logging.getLogger(__name__)
 
     def __getattr__(self, symb):
+        """
+            download the pair
+            https://api.bitfinex.com/v1/symbols
+        :param symb: the cryptocurrency pair, e.g btcusd , ethbtc, ethusd
+        :return:
+        """
         self.logger.debug("__getattr__ called with item:".format(symb))
         url = "{}{}.csv.gz".format(self.baseurl, symb)
         self.logger.debug("getting symb data from {}".format(url))
